application=
{
	name="applestreamingclient",
	description="Apple Streaming Client",
	protocol="dynamiclinklibrary",
	--[[acceptors =
	{
		{
			ip="0.0.0.0",
			port=5544,
			protocol="inboundRtsp"
		}
	},]]--
	aliases=
	{
		"asc",
	},
	--validateHandshake=true,
	--default=true,
}
