application=
{
	name="samplefactory",
	description="asdsadasdsa",
	protocol="dynamiclinklibrary",
	aliases=
	{
		"httpOutboundTest"
	},
	acceptors =
	{
		{
			ip="0.0.0.0",
			port=8989,
			protocol="httpEchoProtocol"
		},
		{
			ip="0.0.0.0",
			port=8988,
			protocol="echoProtocol"
		}
	}
	--validateHandshake=true,
	--default=true,
}